@@ -42,6 +42,7 @@ use super::types::{
     cl_device_atomic_capabilities, cl_device_device_enqueue_capabilities, cl_version
 };
 use super::ffi::cl_ext::{cl_amd_device_topology, cl_device_pci_bus_info_khr,
+    cl_device_integer_dot_product_acceleration_properties_khr,
     CL_DEVICE_COMPUTE_CAPABILITY_MAJOR_NV, CL_DEVICE_COMPUTE_CAPABILITY_MINOR_NV,
     CL_DEVICE_REGISTERS_PER_BLOCK_NV, CL_DEVICE_WARP_SIZE_NV, CL_DEVICE_GPU_OVERLAP_NV,
     CL_DEVICE_KERNEL_EXEC_TIMEOUT_NV, CL_DEVICE_INTEGRATED_MEMORY_NV,
@@ -57,8 +58,13 @@ use super::ffi::cl_ext::{cl_amd_device_topology, cl_device_pci_bus_info_khr,
     CL_DEVICE_AVAILABLE_ASYNC_QUEUES_AMD, CL_DEVICE_PREFERRED_WORK_GROUP_SIZE_AMD,
     CL_DEVICE_MAX_WORK_GROUP_SIZE_AMD, CL_DEVICE_PREFERRED_CONSTANT_BUFFER_SIZE_AMD,
     CL_DEVICE_PCIE_ID_AMD, CL_DEVICE_PCI_BUS_INFO_KHR, CL_DEVICE_INTEGER_DOT_PRODUCT_CAPABILITIES_KHR,
+    CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_8BIT_KHR,
+    CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_4x8BIT_PACKED_KHR,
     CL_DEVICE_UUID_KHR, CL_DRIVER_UUID_KHR, CL_DEVICE_LUID_VALID_KHR,
-    CL_DEVICE_LUID_KHR, CL_DEVICE_NODE_MASK_KHR,
+    CL_DEVICE_LUID_KHR, CL_DEVICE_NODE_MASK_KHR, CL_DEVICE_IP_VERSION_INTEL,
+    CL_DEVICE_ID_INTEL, CL_DEVICE_NUM_SLICES_INTEL, CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL,
+    CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL, CL_DEVICE_NUM_THREADS_PER_EU_INTEL,
+    CL_DEVICE_FEATURE_CAPABILITIES_INTEL,
 };
 use super::{api_info_size, api_info_value, api_info_vector};
 use cl_sys::{clGetDeviceIDs, clGetDeviceInfo};
@@ -331,6 +337,8 @@ pub enum DeviceInfo {
 
     // cl_khr_integer_dot_product extension
     CL_DEVICE_INTEGER_DOT_PRODUCT_CAPABILITIES_KHR = CL_DEVICE_INTEGER_DOT_PRODUCT_CAPABILITIES_KHR as isize,
+    CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_8BIT_KHR = CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_8BIT_KHR as isize,
+    CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_4x8BIT_PACKED_KHR = CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_4x8BIT_PACKED_KHR as isize,
 
     // cl_nv_device_attribute_query extension
     CL_DEVICE_COMPUTE_CAPABILITY_MAJOR_NV = CL_DEVICE_COMPUTE_CAPABILITY_MAJOR_NV as isize,
@@ -368,6 +376,13 @@ pub enum DeviceInfo {
     CL_DEVICE_PREFERRED_CONSTANT_BUFFER_SIZE_AMD = CL_DEVICE_PREFERRED_CONSTANT_BUFFER_SIZE_AMD as isize,
     CL_DEVICE_PCIE_ID_AMD = CL_DEVICE_PCIE_ID_AMD as isize,
     CL_DEVICE_PCI_BUS_INFO_KHR = CL_DEVICE_PCI_BUS_INFO_KHR as isize,
+    CL_DEVICE_IP_VERSION_INTEL = CL_DEVICE_IP_VERSION_INTEL as isize,
+    CL_DEVICE_ID_INTEL = CL_DEVICE_ID_INTEL as isize,
+    CL_DEVICE_NUM_SLICES_INTEL = CL_DEVICE_NUM_SLICES_INTEL as isize,
+    CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL = CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL as isize,
+    CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL = CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL as isize,
+    CL_DEVICE_NUM_THREADS_PER_EU_INTEL = CL_DEVICE_NUM_THREADS_PER_EU_INTEL as isize,
+    CL_DEVICE_FEATURE_CAPABILITIES_INTEL = CL_DEVICE_FEATURE_CAPABILITIES_INTEL as isize,
 }
 
 /// Get specific information about an OpenCL device.  
@@ -429,6 +444,8 @@ pub fn get_device_info(device: cl_device_id, param_name: DeviceInfo) -> Result<I
         | DeviceInfo::CL_DRIVER_UUID_KHR // cl_khr_device_uuid
         | DeviceInfo::CL_DEVICE_LUID_KHR // cl_khr_device_uuid
         | DeviceInfo::CL_DEVICE_LATEST_CONFORMANCE_VERSION_PASSED // CL_VERSION_3_0
+        | DeviceInfo::CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_8BIT_KHR // cl_device_integer_dot_product_acceleration_properties_khr
+        | DeviceInfo::CL_DEVICE_INTEGER_DOT_PRODUCT_ACCELERATION_PROPERTIES_4x8BIT_PACKED_KHR // cl_device_integer_dot_product_acceleration_properties_khr
         | DeviceInfo::CL_DEVICE_TOPOLOGY_AMD // cl_amd_device_attribute_query
         | DeviceInfo::CL_DEVICE_BOARD_NAME_AMD // cl_amd_device_attribute_query
         | DeviceInfo::CL_DEVICE_PCI_BUS_INFO_KHR // cl_khr_pci_bus_info
@@ -522,6 +539,12 @@ pub fn get_device_info(device: cl_device_id, param_name: DeviceInfo) -> Result<I
         | DeviceInfo::CL_DEVICE_GFXIP_MINOR_AMD // cl_amd_device_attribute_query
         | DeviceInfo::CL_DEVICE_AVAILABLE_ASYNC_QUEUES_AMD // cl_amd_device_attribute_query
         | DeviceInfo::CL_DEVICE_PCIE_ID_AMD // cl_amd_device_attribute_query
+        | DeviceInfo::CL_DEVICE_IP_VERSION_INTEL // cl_intel_device_attribute_query
+        | DeviceInfo::CL_DEVICE_ID_INTEL // cl_intel_device_attribute_query
+        | DeviceInfo::CL_DEVICE_NUM_SLICES_INTEL // cl_intel_device_attribute_query
+        | DeviceInfo::CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL // cl_intel_device_attribute_query
+        | DeviceInfo::CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL // cl_intel_device_attribute_query
+        | DeviceInfo::CL_DEVICE_NUM_THREADS_PER_EU_INTEL // cl_intel_device_attribute_query
         => {
             api_info_value!(get_value, cl_uint, clGetDeviceInfo);
             Ok(InfoType::Uint(get_value(device, param_id)?))
@@ -543,7 +566,8 @@ pub fn get_device_info(device: cl_device_id, param_name: DeviceInfo) -> Result<I
         | DeviceInfo::CL_DEVICE_ATOMIC_FENCE_CAPABILITIES // CL_VERSION_3_0
         | DeviceInfo::CL_DEVICE_DEVICE_ENQUEUE_CAPABILITIES // CL_VERSION_3_0
         | DeviceInfo::CL_DEVICE_INTEGER_DOT_PRODUCT_CAPABILITIES_KHR
-         => {
+        | DeviceInfo::CL_DEVICE_FEATURE_CAPABILITIES_INTEL // cl_intel_device_attribute_query
+        => {
             api_info_value!(get_value, cl_ulong, clGetDeviceInfo);
             Ok(InfoType::Ulong(get_value(device, param_id)?))
         }
@@ -638,6 +662,18 @@ pub fn get_device_pci_bus_info_khr(bytes: &[u8]) -> cl_device_pci_bus_info_khr {
     pci_bus_info
 }
 
+/// Convert a u8 slice (e.g. from get_device_info) into a cl_device_integer_dot_product_acceleration_properties_khr structure.
+pub fn get_device_integer_dot_product_acceleration_properties_khr(bytes: &[u8]) -> cl_device_integer_dot_product_acceleration_properties_khr {
+    let size = bytes.len();
+    assert_eq!(size, std::mem::size_of::<cl_device_integer_dot_product_acceleration_properties_khr>());
+    let mut value = cl_device_integer_dot_product_acceleration_properties_khr::default();
+    unsafe {
+        std::slice::from_raw_parts_mut(&mut value as *mut cl_device_integer_dot_product_acceleration_properties_khr as *mut u8, size)
+            .copy_from_slice(bytes);
+    }
+    value
+}
+
 // cl_device_partition_property:
 pub const CL_DEVICE_PARTITION_EQUALLY: cl_device_partition_property = 0x1086;
 pub const CL_DEVICE_PARTITION_BY_COUNTS: cl_device_partition_property = 0x1087;
@@ -1538,6 +1574,62 @@ mod tests {
             Err(e) => println!("OpenCL error, CL_DEVICE_PCI_BUS_INFO_KHR: {}", ClError(e))
         };
 
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_IP_VERSION_INTEL) {
+            Ok(value) => {
+                let value = value.to_uint();
+                println!("CL_DEVICE_IP_VERSION_INTEL: {:?}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_IP_VERSION_INTEL: {}", ClError(e))
+        };
+
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_ID_INTEL) {
+            Ok(value) => {
+                let value = value.to_uint();
+                println!("CL_DEVICE_ID_INTEL: {}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_ID_INTEL: {}", ClError(e))
+        };
+
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_NUM_SLICES_INTEL) {
+            Ok(value) => {
+                let value = value.to_uint();
+                println!("CL_DEVICE_NUM_SLICES_INTEL: {}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_NUM_SLICES_INTEL: {}", ClError(e))
+        };
+
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL) {
+            Ok(value) => {
+                let value = value.to_uint();
+                println!("CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL: {}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_NUM_SUB_SLICES_PER_SLICE_INTEL: {}", ClError(e))
+        };
+
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL) {
+            Ok(value) => {
+                let value = value.to_uint();
+                println!("CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL: {}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_NUM_EUS_PER_SUB_SLICE_INTEL: {}", ClError(e))
+        };
+
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_NUM_THREADS_PER_EU_INTEL) {
+            Ok(value) => {
+                let value = value.to_uint();
+                println!("CL_DEVICE_NUM_THREADS_PER_EU_INTEL: {}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_NUM_THREADS_PER_EU_INTEL: {}", ClError(e))
+        };
+
+        match get_device_info(device_id, DeviceInfo::CL_DEVICE_FEATURE_CAPABILITIES_INTEL) {
+            Ok(value) => {
+                let value = value.to_ulong();
+                println!("CL_DEVICE_FEATURE_CAPABILITIES_INTEL: {}", value)
+            }
+            Err(e) => println!("OpenCL error, CL_DEVICE_FEATURE_CAPABILITIES_INTEL: {}", ClError(e))
+        };
+
         // CL_VERSION_2_0
         if is_opencl_2 {
             let value = get_device_info(device_id, DeviceInfo::CL_DEVICE_IMAGE_PITCH_ALIGNMENT).unwrap();
